@@ -1,6 +1,6 @@
 /*
     gcommon
-    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2015 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -422,16 +422,16 @@ typedef guint32 guintptr;
 * Type Conversion Macros                                                      *
 ******************************************************************************/
 #ifndef GINT_TO_POINTER
-# define GINT_TO_POINTER(i) ((gpointer)(gint)(i))
+# define GINT_TO_POINTER(i) ((gpointer)(glong)(i))
 #endif /* not GINT_TO_POINTER */
 #ifndef GPOINTER_TO_INT
-# define GPOINTER_TO_INT(p) ((gint)(gint)(p))
+# define GPOINTER_TO_INT(p) ((gint)(glong)(p))
 #endif /* not GPOINTER_TO_INT */
 #ifndef GUINT_TO_POINTER
-# define GUINT_TO_POINTER(u) ((gpointer)(guint)(u))
+# define GUINT_TO_POINTER(u) ((gpointer)(gulong)(u))
 #endif /* not GUINT_TO_POINTER */
 #ifndef GPOINTER_TO_UINT
-# define GPOINTER_TO_UINT(p) ((guint)(guint)(p))
+# define GPOINTER_TO_UINT(p) ((guint)(gulong)(p))
 #endif /* not GPOINTER_TO_UINT */
 #ifndef GSIZE_TO_POINTER
 # define GSIZE_TO_POINTER(s) ((gpointer)(gsize)(s))
@@ -643,7 +643,7 @@ guint64 gcommon_swap_64 (const guint64 val);
 #else /* not WORDS_BIGENDIAN */
 # ifndef G_BYTE_ORDER
 #  define G_BYTE_ORDER G_LITTLE_ENDIAN
-# endif /* not G_BYTE_ORDER */
+# endif /* not not G_BYTE_ORDER */
 # ifndef GINT_TO_BE
 #  define GINT_TO_BE(val)      (GINT_SWAP_LE_BE(val))
 # endif /* not GINT_TO_BE */
